# Scikit-Info

## Under development

[![Build Status](https://travis-ci.org/KIT-HYD/scikit-info.svg?branch=master)](https://travis-ci.org/KIT-HYD/scikit-info)
[![Documentation Status](https://readthedocs.org/projects/scikit-info/badge/?version=latest)](https://scikit-info.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/KIT-HYD/scikit-info/branch/master/graph/badge.svg)](https://codecov.io/gh/KIT-HYD/scikit-info)


Scikit-info will be a scipy-styled expansion for information theory.
This module might be rewritten to include Bayes and fuzzy logic functions, as they can come very handy in information therory. Not sure yet.
